logError method

void logError(
  1. String? text, {
  2. String? error,
  3. StackTrace? stackTrace,
  4. String? name,
})

Logs an error with the specified error, text, stackTrace, and fileName.

The error message is associated with the runtime type of the object.

Implementation

void logError(
  String? text, {
  String? error,
  StackTrace? stackTrace,
  String? name,
}) {
  AppLogs.logError(
    text,
    name: name??runtimeType.toString(),
    error: error,
    stackTrace: stackTrace,
  );
}