logError method
Logs an error with the specified error, text, stackTrace, and fileName.
The error message is associated with the runtime type of the object.
Implementation
void logError(
String? text, {
String? error,
StackTrace? stackTrace,
String? name,
}) {
AppLogs.logError(
text,
name: name??runtimeType.toString(),
error: error,
stackTrace: stackTrace,
);
}