logMessage method
Logs a message with the specified text and fileName.
The log message is associated with the runtime type of the object.
Implementation
void logMessage({String? text, String? name}) {
AppLogs.logMessage(text, name: name??runtimeType.toString());
}