logSuccess method
Logs a success message with the specified text and fileName.
The success message is associated with the runtime type of the object.
Implementation
void logSuccess(String? text, {String? fileName}) {
AppLogs.logMessage(text, name: fileName??runtimeType.toString());
}